==> ssp_api-1.2.1.21-sources.jar: com/cloud/hisavana/sdk/api/adx/ANative.java <==
package com.cloud.hisavana.sdk.api.adx;

import android.content.Context;
import android.support.annotation.NonNull;
import android.view.View;
import android.view.ViewGroup;

import com.cloud.hisavana.sdk.api.listener.TaRequest;
import com.cloud.hisavana.sdk.api.view.AAdChoicesView;
import com.cloud.hisavana.sdk.common.bean.TaNativeInfo;
import com.cloud.hisavana.sdk.common.util.AdLogUtil;
import com.cloud.hisavana.sdk.internal.native_.TranNative;

import java.util.List;

/**
 * Created by jianbing.yu on 2019/2/22.
 */
public class ANative {

    private TranNative mNative;
    private static final String TAG = "NativeApi";


    // =============================================================================================


    public ANative(String placementId) {
        mNative = new TranNative(placementId);
    }


    // =============================================================================================


    public void setPlacementId(String placementId) {
        mNative.setPlacementId(placementId);
    }

    /**
     * 设置是否是打底广告
     *
     * @param isDefaultAd
     */
    public void setDefaultAd(boolean isDefaultAd) {
        mNative.setDefaultAd(isDefaultAd);
    }

    /**
     * 设置一次加载多少条
     *
     * @param adCount
     */
    public void setAdCount(int adCount) {
        mNative.setAdCount(adCount);
    }

    public void setAdRequest(@NonNull TaRequest taRequest) {
        mNative.setAdRequest(taRequest);
    }

    public void loadAd(String requestId) {
        mNative.loadAd(requestId);
    }

    public boolean isAdValid(TaNativeInfo taNativeInfo) {
        return mNative.isAdValid(taNativeInfo);
    }

    public boolean isLoading() {
        return mNative.isLoading();
    }

    public void downloadMedia(TaNativeInfo ad) {
        mNative.downloadMedia(ad);
    }

    /**
     * 给广告相关的View注册监听事件
     */
    public void registerViews(@NonNull ViewGroup view, List<View> adContains, TaNativeInfo taNativeInfo) {
        mNative.registerViews(view, adContains, taNativeInfo);
    }

    /**
     * 媒体端自己定义AdChoicesView的位置
     *
     * @param context
     * @param taNativeInfo
     * @return
     */
    public AAdChoicesView getAdChoicesView(Context context, TaNativeInfo taNativeInfo) {
        return mNative.getAdChoicesView(context, taNativeInfo);
    }

    /**
     * 释放资源
     */
    public void destroy() {
        mNative.destroy();
    }

    private boolean isNullApi() {
        if (mNative == null) {
            AdLogUtil.LOG.e(TAG, "no api found");
            return true;
        }
        return false;
    }
}

==> ssp_api-1.3.3.0-sources.jar: com/cloud/hisavana/sdk/api/adx/ANative.java <==
package com.cloud.hisavana.sdk.api.adx;

import android.content.Context;
import android.support.annotation.NonNull;
import android.view.View;
import android.view.ViewGroup;

import com.cloud.hisavana.sdk.api.listener.TaRequest;
import com.cloud.hisavana.sdk.api.view.AAdChoicesView;
import com.cloud.hisavana.sdk.common.bean.TaNativeInfo;
import com.cloud.hisavana.sdk.common.util.AdLogUtil;
import com.cloud.hisavana.sdk.internal.native_.TranNative;

import java.util.List;

/**
 * Created by jianbing.yu on 2019/2/22.
 */
public class ANative {

    private TranNative mNative;
    private static final String TAG = "NativeApi";


    // =============================================================================================


    public ANative(String placementId) {
        mNative = new TranNative(placementId);
    }


    // =============================================================================================


    public void setPlacementId(String placementId) {
        mNative.setPlacementId(placementId);
    }
    /**
     * 设置请求类型
     * @param requestType
     */
    public void setRequestType(int requestType) {
        mNative.setRequestType(requestType);
    }

    /**
     * 设置广告来源
     */
    public void setAdCategory(int adCategory) {
        mNative.setAdCategory(adCategory);
    }

    /**
     * 设置一次加载多少条
     *
     * @param adCount
     */
    public void setAdCount(int adCount) {
        mNative.setAdCount(adCount);
    }

    public void setAdRequest(@NonNull TaRequest taRequest) {
        mNative.setAdRequest(taRequest);
    }

    public void loadAd(String requestId) {
        mNative.loadAd(requestId);
    }

    public boolean isAdValid(TaNativeInfo taNativeInfo) {
        return mNative.isAdValid(taNativeInfo);
    }

    public boolean isLoading() {
        return mNative.isLoading();
    }

    public void downloadMedia(TaNativeInfo ad) {
        mNative.downloadMedia(ad);
    }

    /**
     * 给广告相关的View注册监听事件
     */
    public void registerViews(@NonNull ViewGroup view, List<View> adContains, TaNativeInfo taNativeInfo) {
        mNative.registerViews(view, adContains, taNativeInfo);
    }

    /**
     * 媒体端自己定义AdChoicesView的位置
     *
     * @param context
     * @param taNativeInfo
     * @return
     */
    public AAdChoicesView getAdChoicesView(Context context, TaNativeInfo taNativeInfo) {
        return mNative.getAdChoicesView(context, taNativeInfo);
    }

    /**
     * 释放资源
     */
    public void destroy() {
        mNative.destroy();
    }
}
